==> g4f-0.3.1.3.tar.gz: g4f-0.3.1.3/g4f/client/stubs.py <==
from __future__ import annotations

from typing import Union

class Model():
    ...

class ChatCompletion(Model):
    def __init__(
        self,
        content: str,
        finish_reason: str,
        completion_id: str = None,
        created: int = None
    ):
        self.id: str = f"chatcmpl-{completion_id}" if completion_id else None
        self.object: str = "chat.completion"
        self.created: int = created
        self.model: str = None
        self.provider: str = None
        self.choices = [ChatCompletionChoice(ChatCompletionMessage(content), finish_reason)]
        self.usage: dict[str, int] = {
            "prompt_tokens": 0, #prompt_tokens,
            "completion_tokens": 0, #completion_tokens,
            "total_tokens": 0, #prompt_tokens + completion_tokens,
        }

    def to_json(self):
        return {
            **self.__dict__,
            "choices": [choice.to_json() for choice in self.choices]
        }

class ChatCompletionChunk(Model):
    def __init__(
        self,
        content: str,
        finish_reason: str,
        completion_id: str = None,
        created: int = None
    ):
        self.id: str = f"chatcmpl-{completion_id}" if completion_id else None
        self.object: str = "chat.completion.chunk"
        self.created: int = created
        self.model: str = None
        self.provider: str = None
        self.choices = [ChatCompletionDeltaChoice(ChatCompletionDelta(content), finish_reason)]

    def to_json(self):
        return {
            **self.__dict__,
            "choices": [choice.to_json() for choice in self.choices]
        }

class ChatCompletionMessage(Model):
    def __init__(self, content: Union[str, None]):
        self.role = "assistant"
        self.content = content

    def to_json(self):
        return self.__dict__

class ChatCompletionChoice(Model):
    def __init__(self, message: ChatCompletionMessage, finish_reason: str):
        self.index = 0
        self.message = message
        self.finish_reason = finish_reason

    def to_json(self):
        return {
            **self.__dict__,
            "message": self.message.to_json()
        }

class ChatCompletionDelta(Model):
    content: Union[str, None] = None

    def __init__(self, content: Union[str, None]):
        if content is not None:
            self.content = content
            self.role = "assistant"

    def to_json(self):
        return self.__dict__

class ChatCompletionDeltaChoice(Model):
    def __init__(self, delta: ChatCompletionDelta, finish_reason: Union[str, None]):
        self.index = 0
        self.delta = delta
        self.finish_reason = finish_reason

    def to_json(self):
        return {
            **self.__dict__,
            "delta": self.delta.to_json()
        }

class Image(Model):
    url: str

    def __init__(self, url: str) -> None:
        self.url = url

class ImagesResponse(Model):
    data: list[Image]

    def __init__(self, data: list) -> None:
        self.data = data

==> g4f-0.3.3.1.tar.gz: g4f-0.3.3.1/g4f/client/stubs.py <==
from __future__ import annotations

from typing import Union

class Model():
    ...

class ChatCompletion(Model):
    def __init__(
        self,
        content: str,
        finish_reason: str,
        completion_id: str = None,
        created: int = None
    ):
        self.id: str = f"chatcmpl-{completion_id}" if completion_id else None
        self.object: str = "chat.completion"
        self.created: int = created
        self.model: str = None
        self.provider: str = None
        self.choices = [ChatCompletionChoice(ChatCompletionMessage(content), finish_reason)]
        self.usage: dict[str, int] = {
            "prompt_tokens": 0, #prompt_tokens,
            "completion_tokens": 0, #completion_tokens,
            "total_tokens": 0, #prompt_tokens + completion_tokens,
        }

    def to_json(self):
        return {
            **self.__dict__,
            "choices": [choice.to_json() for choice in self.choices]
        }

class ChatCompletionChunk(Model):
    def __init__(
        self,
        content: str,
        finish_reason: str,
        completion_id: str = None,
        created: int = None
    ):
        self.id: str = f"chatcmpl-{completion_id}" if completion_id else None
        self.object: str = "chat.completion.chunk"
        self.created: int = created
        self.model: str = None
        self.provider: str = None
        self.choices = [ChatCompletionDeltaChoice(ChatCompletionDelta(content), finish_reason)]

    def to_json(self):
        return {
            **self.__dict__,
            "choices": [choice.to_json() for choice in self.choices]
        }

class ChatCompletionMessage(Model):
    def __init__(self, content: Union[str, None]):
        self.role = "assistant"
        self.content = content

    def to_json(self):
        return self.__dict__

class ChatCompletionChoice(Model):
    def __init__(self, message: ChatCompletionMessage, finish_reason: str):
        self.index = 0
        self.message = message
        self.finish_reason = finish_reason

    def to_json(self):
        return {
            **self.__dict__,
            "message": self.message.to_json()
        }

class ChatCompletionDelta(Model):
    content: Union[str, None] = None

    def __init__(self, content: Union[str, None]):
        if content is not None:
            self.content = content
            self.role = "assistant"

    def to_json(self):
        return self.__dict__

class ChatCompletionDeltaChoice(Model):
    def __init__(self, delta: ChatCompletionDelta, finish_reason: Union[str, None]):
        self.index = 0
        self.delta = delta
        self.finish_reason = finish_reason

    def to_json(self):
        return {
            **self.__dict__,
            "delta": self.delta.to_json()
        }

class Image(Model):
    def __init__(self, url: str = None, b64_json: str = None, revised_prompt: str = None) -> None:
        if url is not None:
            self.url = url
        if b64_json is not None:
            self.b64_json = b64_json
        if revised_prompt is not None:
            self.revised_prompt = revised_prompt

    def to_json(self):
        return self.__dict__

class ImagesResponse(Model):
    def __init__(self, data: list[Image], created: int = 0) -> None:
        self.data = data
        self.created = created

    def to_json(self):
        return {
            **self.__dict__,
            "data": [image.to_json() for image in self.data]
        }
